pub enum Error {
InvalidOpcode(u16),
InvalidOpcodeString(String),
InvalidIndexedOperand(Operand),
InvalidAccessSize(AccessType, DataType),
Unimplemented(&'static str),
IoError(Error),
}Expand description
Variants
InvalidOpcode(u16)
Invalid Opcode
In the documention, all undefined opcodes are marked as “Reserved to DIGITAL”, so this error is like a reserved operand error.
InvalidOpcodeString(String)
Invalid Opcode String
In the documention, all undefined opcodes are marked as “Reserved to DIGITAL”, so this error is like a reserved operand error.
InvalidIndexedOperand(Operand)
Invalid Indexed Operand
InvalidAccessSize(AccessType, DataType)
Invalid Access Type and Data Type Combination
Unimplemented(&'static str)
Unimplemented Feature
This is an unimplemented feature. This error should go away once development is complete.
IoError(Error)
Passtrhough I/O Error